==> bea_flutter_package-0.76.129.tar.gz: lib/bea_services/core/bea_defaults_manager.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/error/bea_error.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/defaults/result_defaults.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/input/generic_server_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/output/bea_session.dart';
import 'package:bea_flutter_package/bea_services/utils/url_utils.dart';
import 'package:f_logs/model/flog/flog.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:http/http.dart';

import '../dtos/flutter_models/output/generic_server_response.dart';
import 'bea_service_manager.dart';

class BeaDefaultsManager{
  final BeaServiceManager bsm;

  String _baseUrl = "";
  FlutterSecureStorage storage;

  BeaDefaultsManager(this.bsm){
    try{
      if(bsm == null){
        throw new Exception("BeaServiceManager not initialized");
      }

      _baseUrl = bsm.getBaseUrl();
      storage = bsm.getBeaStorage();
    }on Exception catch (e){
      print('Initialization ${this.runtimeType.toString()} error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "Costructor",
          text: 'Initialization ${this.runtimeType.toString()} error - $e');
      throw e;
    }
  }

  Future<GenericServerResponse<BeaResultDefaults>> getAllDefaults(GenericServerInput input) async {
    GenericServerResponse<BeaResultDefaults> genericServerResponse = new GenericServerResponse<BeaResultDefaults>();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_GET_ALL_DEFAULTS);

      String jsonInput = '{"filter": "${input.basePagination.filter}",'
          '"sorting": "${input.basePagination.sorting}",'
          '"skipCount": ${input.basePagination.skipCount},'
          '"maxResultCount": ${input.basePagination.maxResultCount}}';

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = BeaResultDefaults.fromJson(jsonDecode(response.body)['result']);
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.body)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error to get BEA defaults');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "getAllDefaults",
          text: 'Error to get BEA defaults - $e');
      throw e;
    }

    return genericServerResponse;
  }
}

==> bea_flutter_package-1.1.1.tar.gz: lib/bea_services/core/bea_defaults_manager.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/error/bea_error.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/defaults/result_defaults.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/input/generic_server_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/output/bea_session.dart';
import 'package:bea_flutter_package/bea_services/utils/url_utils.dart';
import 'package:dio/dio.dart';
import 'package:f_logs/model/flog/flog.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';

import '../dtos/flutter_models/output/generic_server_response.dart';
import 'bea_service_manager.dart';

class BeaDefaultsManager{
  final BeaServiceManager bsm;

  String _baseUrl = "";
  FlutterSecureStorage storage;

  BeaDefaultsManager(this.bsm){
    try{
      if(bsm == null){
        throw new Exception("BeaServiceManager not initialized");
      }

      _baseUrl = bsm.getBaseUrl();
      storage = bsm.getBeaStorage();
    }on Exception catch (e){
      print('Initialization ${this.runtimeType.toString()} error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "Costructor",
          text: 'Initialization ${this.runtimeType.toString()} error - $e');
      throw e;
    }
  }

  Future<GenericServerResponse<BeaResultDefaults>> getAllDefaults(GenericServerInput input) async {
    GenericServerResponse<BeaResultDefaults> genericServerResponse = new GenericServerResponse<BeaResultDefaults>();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_GET_ALL_DEFAULTS);

      String jsonInput = '{"filter": "${input.basePagination.filter}",'
          '"sorting": "${input.basePagination.sorting}",'
          '"skipCount": ${input.basePagination.skipCount},'
          '"maxResultCount": ${input.basePagination.maxResultCount}}';

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = BeaResultDefaults.fromJson(jsonDecode(response.data)['result']);
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.data)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error to get BEA defaults');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "getAllDefaults",
          text: 'Error to get BEA defaults - $e');
      throw e;
    }

    return genericServerResponse;
  }
}
